// Copyright 2020 Sarbagya Dhaubanjar. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'package:dartz/dartz.dart' hide State;
import 'package:flutter/material.dart';
import 'package:flutter_yt_player/src/widgets/pop_up.dart';

import '../enums/playback_rate.dart';
import '../utils/youtube_player_controller.dart';

/// A widget to display playback speed changing button.
class PlaybackSpeedButton extends StatefulWidget {
  /// Overrides the default [YoutubePlayerController].
  final YoutubePlayerController controller;

  /// Defines icon for the button.
  final Widget icon;

  /// Creates [PlaybackSpeedButton] widget.
  const PlaybackSpeedButton({
    this.controller,
    this.icon,
  });

  @override
  _PlaybackSpeedButtonState createState() => _PlaybackSpeedButtonState();
}

class _PlaybackSpeedButtonState extends State<PlaybackSpeedButton> {
  YoutubePlayerController _controller;

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    _controller = YoutubePlayerController.of(context);
    if (_controller == null) {
      assert(
        widget.controller != null,
        '\n\nNo controller could be found in the provided context.\n\n'
        'Try passing the controller explicitly.',
      );
      _controller = widget.controller;
    }
  }

  @override
  Widget build(BuildContext context) {
    return CustomPopUpButton(
      value: _controller.value.playbackRate,
      onChanged: _controller.setPlaybackRate,
      child: Padding(
        padding: const EdgeInsets.fromLTRB(8.0, 8.0, 0.0, 8.0),
        child: widget.icon ??
            Image.asset(
              'assets/speedometer.webp',
              package: 'flutter_yt_player',
              width: 20.0,
              height: 20.0,
              color: Colors.white,
            ),
      ),
      itemBuilder: [
        Tuple2(_popUpItem('2.0x', PlaybackRate.twice), PlaybackRate.twice),
        Tuple2(_popUpItem('1.75x', PlaybackRate.oneAndAThreeQuarter),
            PlaybackRate.oneAndAThreeQuarter),
        Tuple2(_popUpItem('1.5x', PlaybackRate.oneAndAHalf),
            PlaybackRate.oneAndAHalf),
        Tuple2(_popUpItem('1.25x', PlaybackRate.oneAndAQuarter),
            PlaybackRate.oneAndAQuarter),
        Tuple2(_popUpItem('Normal', PlaybackRate.normal), PlaybackRate.normal),
        Tuple2(_popUpItem('0.75x', PlaybackRate.threeQuarter),
            PlaybackRate.threeQuarter),
        Tuple2(_popUpItem('0.5x', PlaybackRate.half), PlaybackRate.half),
        Tuple2(_popUpItem('0.25x', PlaybackRate.quarter), PlaybackRate.quarter),
      ],
    );
  }

  Widget _popUpItem(String text, double rate) {
    return CheckedPopupMenuItem(
      checked: _controller.value.playbackRate == rate,
      child: Text(text),
      value: rate,
    );
  }
}
